package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.TElectronicFence;
import com.ruoyi.system.domain.vo.AMapFenceVo;
import com.ruoyi.system.domain.vo.ElectronicFenceVo;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-09-14
 */
public interface ITElectronicFenceService {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TElectronicFence selectTElectronicFenceById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tElectronicFence 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TElectronicFence> selectTElectronicFenceList(TElectronicFence tElectronicFence);

    /**
     * 新增【请填写功能名称】
     *
     * @param tElectronicFence 【请填写功能名称】
     * @return 结果
     */
    public int insertTElectronicFence(TElectronicFence tElectronicFence);

    /**
     * 修改【请填写功能名称】
     *
     * @param tElectronicFence 【请填写功能名称】
     * @return 结果
     */
    public int updateTElectronicFence(TElectronicFence tElectronicFence);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTElectronicFenceByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTElectronicFenceById(Long id);

    int insertTElectronicFenceVo(ElectronicFenceVo electronicFenceVo);

    /**
     * 通过deviceId获取围栏列表
     *
     * @param deviceId
     * @return
     */
    List<AMapFenceVo> selectTElectronicFenceListByDeviceId(Long deviceId);

    /**
     * 通过围栏id更新
     *
     * @param tElectronicFenceEditVo
     * @return
     */
    int updateTElectronicFenceEditVo(ElectronicFenceVo tElectronicFenceEditVo);

}
