package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.to.AMapBaseTo;
import com.ruoyi.system.domain.vo.AMapFenceVo;
import com.ruoyi.system.domain.vo.ElectronicFenceVo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TElectronicFence;
import com.ruoyi.system.service.ITElectronicFenceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2023-09-14
 */
@RestController
@RequestMapping("/system/electronic/fence")
public class TElectronicFenceController extends BaseController {
    @Autowired
    private ITElectronicFenceService tElectronicFenceService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:fence:list')")
    @GetMapping("/list")
    public TableDataInfo list(TElectronicFence tElectronicFence) {
        startPage();
        List<TElectronicFence> list = tElectronicFenceService.selectTElectronicFenceList(tElectronicFence);
        return getDataTable(list);
    }


    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:fence:list')")
    @GetMapping("/list/device/{deviceId}")
    public TableDataInfo list(@PathVariable("deviceId") Long deviceId) {
        startPage();
        List<AMapFenceVo> list = tElectronicFenceService.selectTElectronicFenceListByDeviceId(deviceId);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:fence:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TElectronicFence tElectronicFence) {
        List<TElectronicFence> list = tElectronicFenceService.selectTElectronicFenceList(tElectronicFence);
        ExcelUtil<TElectronicFence> util = new ExcelUtil<TElectronicFence>(TElectronicFence.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fence:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tElectronicFenceService.selectTElectronicFenceById(id));
    }

//    /**
//     * 新增【请填写功能名称】
//     */
//    @PreAuthorize("@ss.hasPermi('system:fence:add')")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody TElectronicFence tElectronicFence) {
//        return toAjax(tElectronicFenceService.insertTElectronicFence(tElectronicFence));
//    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:fence:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated ElectronicFenceVo electronicFenceVo) {
        electronicFenceVo.setUsdId(getUserId());
        return toAjax(tElectronicFenceService.insertTElectronicFenceVo(electronicFenceVo));
    }

//    /**
//     * 修改【请填写功能名称】
//     */
//    @PreAuthorize("@ss.hasPermi('system:fence:edit')")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody TElectronicFence tElectronicFence) {
//        return toAjax(tElectronicFenceService.updateTElectronicFence(tElectronicFence));
//    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:fence:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping("/edit")
    public AjaxResult edit(@RequestBody ElectronicFenceVo tElectronicFenceEditVo) {
        return toAjax(tElectronicFenceService.updateTElectronicFenceEditVo(tElectronicFenceEditVo));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:fence:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tElectronicFenceService.deleteTElectronicFenceByIds(ids));
    }
}
